OC.L10N.register(
    "imprint",
    {
    "Legal notice" : "Leĝa sciigilo",
    "Nothing here yet" : "Nenio ĉeestas ankoraŭ",
    "The content of the legal notice has to be configured first" : "La enhavo de la leĝa sciigilo devas agordiĝi unue",
    "That configuration has to be done by the system administration." : "Tiun agordon devas fari la sistemadministranto.",
    "Header left" : "Maldekstro de kapo",
    "Header right" : "Dekstro de kapo",
    "As guest" : "Gaste",
    "At login" : "Ĉe ensaluto",
    "Application" : "Aplikaĵo",
    "Content" : "Enhavo"
},
"nplurals=2; plural=(n != 1);");
